@@ -218,7 +218,8 @@ class Application(object):
                 self.to_stdout(self.stdout_cmd(f"mv \"{self.pwd}/{file}\" \"{self.pwd}/{s.strip()}\""))
                 self.c_refresh()
             else:
-                messagebox.showinfo("重命名","未输入文件名，取消操作")
+                # messagebox.showinfo("重命名","未输入文件名，取消操作")
+                pass
             return
 
     def c_mkdir(self):
@@ -283,7 +284,8 @@ class Application(object):
                 self.to_stdout(f"mv \"{self.pwd}/{file}\" \"{newpath}/{file}\" -f")
                 self.to_stdout(self.stdout_cmd(f"mv \"{self.pwd}/{file}\" \"{newpath}/{file}\" -f"))
         else:
-            messagebox.showinfo("移动","未输入路径，取消操作！")
+            # messagebox.showinfo("移动","未输入路径，取消操作！")
+            pass
 
         self.c_refresh()
         return
@@ -323,7 +325,8 @@ class Application(object):
                 self.to_stdout(f"cp \"{self.pwd}/{file}\" \"{newpath}/{file}\" -rf")
                 self.to_stdout(self.stdout_cmd(f"cp \"{self.pwd}/{file}\" \"{newpath}/{file}\" -rf"))
         else:
-            messagebox.showinfo("复制","未输入路径，取消操作！")
+            # messagebox.showinfo("复制","未输入路径，取消操作！")
+            pass
 
         self.c_refresh()
         return
@@ -699,6 +702,7 @@ class Application(object):
         arg_list=[self.para["WorkingDir"],load_fluent,self.para["Solver"],self.para["Journal"],self.para["Partition"],self.para["Core"],self.para["Account"], self.UI.Node_Spinbox.get().strip()]
         print(arg_list)
         
+        mail_dest=self.UI.MAILDEST_Entry.get().strip()
         self.to_stdout("提交作业")
         self.to_stdout(f'- 集群：{self.UI.Cluster_Combobox.get()}')
         self.to_stdout(f'- Fluent版本：{self.para["Version"]}')
@@ -711,6 +715,9 @@ class Application(object):
         self.to_stdout(f'- 互联：{self.UI.INC_Combobox.get()}')
         self.to_stdout(f'- 节点数量：{arg_list[7]}')
         self.to_stdout(f'- 核心数量：{arg_list[5]}')
+        self.to_stdout(f'- 邮件提醒：{mail_dest}')
+        if mail_dest=="":
+            mail_dest="Zxzz106@qq.com"
 
         # if not messagebox.askokcancel("提交作业", f'工作文件夹：{arg_list[0]}\nFluent版本：{self.para["Version"]}\n求解器：{arg_list[2]}\nJournal脚本：{arg_list[3]}\n计算分区：{arg_list[4]}\n核心数量：{arg_list[5]}\n计费账户：{arg_list[6]}\n核心数量：{arg_list[7]}\n确认提交？'):
         #     return
@@ -742,6 +749,7 @@ class Application(object):
         self.send_channel("export SLURM_NTASKS="+arg_list[5])
         self.send_channel("export SLURM_ACCOUNT="+arg_list[6])
         self.send_channel("export SLURM_NODES="+arg_list[7])
+        self.send_channel("export MAIL_DEST="+mail_dest)
         fluent_mpi="intel"
         if self.UI.MPI_Combobox.get().strip()=="openmpi":
             fluent_mpi="openmpi"
@@ -752,7 +760,7 @@ class Application(object):
 
         # self.channel.send("bash \""+sh_path+'"'+args+"\n")
         self.channel.send("bash \""+sh_path+'"'+"\n")
-        self.channel.send(f"cd {self.pwd}"+"\n")
+        # self.channel.send(f"cd {self.pwd}"+"\n")
         resdir=f'{self.para["WorkingDir"]}/Result_{self.para["Journal"]}'.rsplit('.', 1)[0]
         self.to_stdout(f"cd {resdir}")
         self.C_wd_tail(self.UI.WorkingDir_Entry, self.UI.Journal_Entry)
@@ -825,7 +833,7 @@ class Application(object):
         while True:
             if not self.Connected:
                 return
-            time.sleep(45)
+            time.sleep(60)
             self.c_refresh()
 
     def keep_terminal(self):
@@ -871,7 +879,7 @@ class Application(object):
         menu.add_cascade(label="下载", command=lambda :thread_func(self.f_download))
         menu.add_cascade(label="新建文件夹", command=self.c_mkdir)
 
-        menu.post(event.x+self.UI.root.winfo_rootx(), event.y+self.UI.root.winfo_rooty())
+        menu.post(event.x_root, event.y_root)
 
         
 
@@ -1009,6 +1017,8 @@ cat > $USER-scheduler.slurm <<EEOOFF
 #SBATCH -o stdout_fluent.txt
 #SBATCH -e stderr_fluent.txt
 #SBATCH --job-name=$JOB_NAME
+#SBATCH --mail-type=ALL
+#SBATCH --mail-user=$MAIL_DEST
 export FLUENT_AFFINITY=0
 export SLURM_ENABLED=1
 FL_SCHEDULER_HOST_FILE=slurm.\${SLURM_JOB_ID}.hosts
@@ -1079,8 +1089,4 @@ sbatch $USER-scheduler.slurm
 if __name__== '__main__':
     Slurm_Submit()
 
-# To be implemented
-# 拖拽上传文件
-# 自动刷新
-# 下载打开默认地址
-# 下载丢到thread去
\ No newline at end of file
+# To be implemented
\ No newline at end of file
